@@ -35,9 +35,9 @@
  *
  */
 
-#include <string.h>
 #include "gmconfwidgets.h"
 
+#include <string.h>
 
 /* GTK Callbacks */
 /*
@@ -69,7 +69,7 @@ entry_activate_changed (GtkWidget *w,
  */
 gboolean
 entry_focus_changed (GtkWidget  *w,
-                     GdkEventFocus *ev,
+                     G_GNUC_UNUSED GdkEventFocus *ev,
                      gpointer data)
 {
   gchar *key = NULL;
@@ -97,7 +97,7 @@ entry_focus_changed (GtkWidget  *w,
  *                 should be of type string.
  */
 void
-entry_changed_nt (gpointer cid, 
+entry_changed_nt (G_GNUC_UNUSED gpointer cid, 
 		  GmConfEntry *entry,
 		  gpointer data)
 {
@@ -171,7 +171,7 @@ toggle_changed (GtkCheckButton *but,
  *"                should be of type boolean.
  */
 void
-toggle_changed_nt (gpointer cid, 
+toggle_changed_nt (G_GNUC_UNUSED gpointer cid, 
 		   GmConfEntry *entry,
 		   gpointer data)
 {
@@ -223,7 +223,7 @@ adjustment_changed (GtkAdjustment *adj,
 
 
 void
-adjustment_changed_nt (gpointer cid, 
+adjustment_changed_nt (G_GNUC_UNUSED gpointer cid, 
 		       GmConfEntry *entry,
 		       gpointer data)
 {
@@ -243,7 +243,8 @@ adjustment_changed_nt (gpointer cid,
 				     0, 0, NULL,
 				     (gpointer) adjustment_changed,
 				     NULL);
-    if (gtk_adjustment_get_value (GTK_ADJUSTMENT (s)) != current_value)
+    if (gtk_adjustment_get_value (GTK_ADJUSTMENT (s)) > current_value
+        || gtk_adjustment_get_value (GTK_ADJUSTMENT (s)) < current_value)
       gtk_adjustment_set_value (GTK_ADJUSTMENT (s), current_value);
     g_signal_handlers_unblock_matched (G_OBJECT (s),
 				       G_SIGNAL_MATCH_FUNC,
@@ -262,21 +263,20 @@ adjustment_changed_nt (gpointer cid,
  * PRE          :  Non-Null data corresponding to int the config key to modify.
  */
 void
-int_option_menu_changed (GtkWidget *menu,
+int_option_menu_changed (GtkWidget *option_menu,
 			 gpointer data)
 {
   gchar *key = NULL;
-  GtkWidget *active_item = NULL;
-  guint item_index = -1;
-  
-  key = (gchar *) data;
-  
-  active_item = gtk_menu_get_active (GTK_MENU (menu));
-  item_index = g_list_index (GTK_MENU_SHELL (GTK_MENU (menu))->children, 
-			     active_item);
+  unsigned int current_value = 0;
+  unsigned int i = 0;
 
-  if (gm_conf_get_int (key) != item_index)
-    gm_conf_set_int (key, item_index);
+  key = (gchar *) data;
+
+  i = gtk_combo_box_get_active (GTK_COMBO_BOX (option_menu));
+  current_value = gm_conf_get_int (key);
+
+  if (i != current_value)
+    gm_conf_set_int (key, i);
 }
 
 
@@ -289,7 +289,7 @@ int_option_menu_changed (GtkWidget *menu,
  *                 should be of type integer.
  */
 void
-int_option_menu_changed_nt (gpointer cid, 
+int_option_menu_changed_nt (G_GNUC_UNUSED gpointer cid, 
 			    GmConfEntry *entry,
 			    gpointer data)
 {
@@ -308,17 +308,18 @@ int_option_menu_changed_nt (gpointer cid,
 				     0, 0, NULL,
 				     (gpointer) int_option_menu_changed,
 				     NULL);
-    if (current_value != gtk_option_menu_get_history (GTK_OPTION_MENU (e)))
-	gtk_option_menu_set_history (GTK_OPTION_MENU (e), current_value);
-    g_signal_handlers_block_matched (G_OBJECT (e),
-				     G_SIGNAL_MATCH_FUNC,
-				     0, 0, NULL,
-				     (gpointer) int_option_menu_changed,
-				     NULL);
+    if (current_value != gtk_combo_box_get_active (GTK_COMBO_BOX (e)))
+	gtk_combo_box_set_active (GTK_COMBO_BOX (e), current_value);
+    g_signal_handlers_unblock_matched (G_OBJECT (e),
+                                       G_SIGNAL_MATCH_FUNC,
+                                       0, 0, NULL,
+                                       (gpointer) int_option_menu_changed,
+                                       NULL);
     gdk_threads_leave ();
   }
 }
 
+
 /* DESCRIPTION  :  This function is called when a string option menu changes.
  * BEHAVIOR     :  Updates the key given as parameter to the new value of the
  *                 string option menu.  
@@ -326,28 +327,29 @@ int_option_menu_changed_nt (gpointer cid,
  *                 modify.
  */
 void
-string_option_menu_changed (GtkWidget *menu,
+string_option_menu_changed (GtkWidget *option_menu,
 			    gpointer data)
 {
-  GtkWidget *active_item = NULL;
-  const gchar *text = NULL;
-
+  GtkTreeModel *model = NULL;
+  GtkTreeIter iter;
+  
+  gchar *text = NULL;
   gchar *current_value = NULL;
   gchar *key = NULL;
 
   key = (gchar *) data;
 
+  model = gtk_combo_box_get_model (GTK_COMBO_BOX (option_menu));
+  if (gtk_combo_box_get_active_iter (GTK_COMBO_BOX (option_menu), &iter)) {
 
-  active_item = gtk_menu_get_active (GTK_MENU (menu));
-  if (!active_item)
-    text = "";
-  else if (GTK_BIN (active_item)->child)
-    text = gtk_label_get_text (GTK_LABEL (GTK_BIN (active_item)->child));
+    gtk_tree_model_get (GTK_TREE_MODEL (model), &iter, 0, &text, -1);
+    current_value = gm_conf_get_string (key);
 
-  current_value = gm_conf_get_string (key);
+    if (text && current_value && strcmp (text, current_value))
+      gm_conf_set_string (key, text);
 
-  if (text && current_value && strcmp (text, current_value))
-    gm_conf_set_string (key, text);
+    g_free (text);
+  }
 }
 
 
@@ -360,42 +362,50 @@ string_option_menu_changed (GtkWidget *menu,
  *                 should be of type string.
  */
 void
-string_option_menu_changed_nt (gpointer cid, 
+string_option_menu_changed_nt (G_GNUC_UNUSED gpointer cid, 
 			       GmConfEntry *entry,
 			       gpointer data)
 {
   int cpt = 0;
-  GtkWidget *e = NULL;
-  GtkWidget *label = NULL;
-  GList *glist = NULL;
-  gpointer mydata;
+  int count = 0;
 
+  GtkTreeModel *model = NULL;
+  GtkTreeIter iter;
+  
+  GtkWidget *e = NULL;
+  
+  gchar *text = NULL;
+  
   if (gm_conf_entry_get_type (entry) == GM_CONF_STRING) {
    
     gdk_threads_enter ();
 
     e = GTK_WIDGET (data);
     
-    /* We set the new value for the widget */
-    glist = 
-      g_list_first (GTK_MENU_SHELL (GTK_MENU (GTK_OPTION_MENU (e)->menu))->children);
-    
-    while ((mydata = g_list_nth_data (glist, cpt)) != NULL) {
+    model = gtk_combo_box_get_model (GTK_COMBO_BOX (e));
+    count = gtk_tree_model_iter_n_children (model, NULL);
+    gtk_tree_model_get_iter_first (model, &iter);
 
-      label = GTK_BIN (mydata)->child;
-      if (label && !strcmp (gtk_label_get_text (GTK_LABEL (label)), 
-			    gm_conf_entry_get_string (entry)))
-	break;
-      cpt++; 
-    } 
+    for (cpt = 0 ; cpt < count ; cpt++) {
+
+      gtk_tree_model_get (model, &iter, 0, &text, -1);
+      if (text && !strcmp (text, gm_conf_entry_get_string (entry))) {
+       
+        g_free (text);
+        break;
+      }
+      gtk_tree_model_iter_next (model, &iter);
+      
+      g_free (text);
+    }
 
     g_signal_handlers_block_matched (G_OBJECT (e),
 				     G_SIGNAL_MATCH_FUNC,
 				     0, 0, NULL,
 				     (gpointer) string_option_menu_changed,
 				     NULL);
-    if (gtk_option_menu_get_history (GTK_OPTION_MENU (data)) != cpt)
-      gtk_option_menu_set_history (GTK_OPTION_MENU (data), cpt);
+    if (gtk_combo_box_get_active (GTK_COMBO_BOX (data)) != cpt)
+      gtk_combo_box_set_active (GTK_COMBO_BOX (data), cpt);
     g_signal_handlers_unblock_matched (G_OBJECT (e),
 				       G_SIGNAL_MATCH_FUNC,
 				       0, 0, NULL,
